####################
ebilabドキュメント
####################

:code:`ebilab` は研究に使っているコードを整理している python パッケージです。

* :py:mod:`ebilab.experiment` : 実験装置を制御するためのパッケージ
* :py:mod:`ebilab.analysis` : データ解析のためのパッケージ (未完成)

Python 3.10.7 で動作確認されています。


****************************************
目次
****************************************


.. toctree::
    :maxdepth: 1

    installation
    changelog

.. toctree::
    :maxdepth: 1
    :caption: チュートリアル

    tutorial/version
    tutorial/experiment_device
    tutorial/experiment
    tutorial/analysis

.. toctree::
    :caption: Reference
    :maxdepth: 1

    api/index

.. toctree::
    :caption: 索引
    :maxdepth: 1

    genindex

